@@ -63,7 +63,9 @@ __all__ = (
     "TargetStatusType",
     "TrafficRoutingTypeType",
     "TriggerEventTypeType",
+    "CodeDeployServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
 )
@@ -185,6 +187,7 @@ TriggerEventTypeType = Literal[
     "InstanceStart",
     "InstanceSuccess",
 ]
+CodeDeployServiceName = Literal["codedeploy"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -216,6 +219,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -338,6 +342,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -486,6 +491,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_application_revisions",
     "list_applications",
